@@ -19,9 +19,11 @@ pymysql.install_as_MySQLdb()
 
 
 class ForApp():
-    def __init__(self, import_name, MONGO_HOST_URL, secret_key, log_folder=None, root_path=None,
+    def __init__(self, import_name, MONGO_HOST_URL, secret_key,
+                 log_folder=None, root_path=None,
                  need_before_request=True,
                  need_after_request=True,
+                 page_size=10
                  ):
         self.import_name = import_name
         self.log_folder = log_folder
@@ -47,7 +49,8 @@ class ForApp():
         app.config['PERMANENT_SESSION_LIFETIME'] = datetime.timedelta(days=7)
         app.config[' SESSION_MONGODB'] = pymongo.MongoClient(MONGO_HOST_URL)
         app.config['SESSION_PERMANENT'] = True
-        app.config['SESSION_USE_SIGNER'] = False  # 是否对发送到浏览器上session的cookie值进行加密
+        # 是否对发送到浏览器上session的cookie值进行加密
+        app.config['SESSION_USE_SIGNER'] = False
         app.config['SESSION_KEY_PREFIX'] = 'eic_session:'  # 保存到session中的值的前缀
         app.config['SESSION_MONGODB_DB'] = SessionDB
 
@@ -67,7 +70,7 @@ class ForApp():
                 params = {}
                 if request.args:
                     params.update(request.args.to_dict(flat=True))
-                if request.method != 'GET' and request.json:
+                if request.is_json and request.get_data() and request.json:
                     if type(request.json) == type([]):
                         for x in request.json:
                             params.update(x)
@@ -86,6 +89,16 @@ class ForApp():
                     pass
                 g.ip = ip
                 g.error = False
+
+                g.current_device = params.get('current_device', '')
+                # 当前第几页
+                page = params.get('page', '0')
+                g.page = int(page) if page else 0
+                # 每页面默认取出数量：20
+                g.page_size = int(params.get('page_size', page_size))
+                # 为了防止过分访问，限制最大50
+                g.page_size = 20 if g.page_size < 1 or g.page_size > 50 else g.page_size
+                g.page = 0 if g.page < 0 else g.page
         if need_after_request:
             @app.after_request
             def after_request(response):
